# MustOpt

![version badge](https://img.shields.io/pypi/v/mustopt.svg?style=for-the-badge)
![download counter badge](https://img.shields.io/pypi/dm/mustopt.svg?style=for-the-badge&logo=pypi)

⚡️Robust optional value container
